<?php

namespace Drupal\expense_tracker;

use Drupal\Core\Entity\ContentEntityInterface;

/**
 * Provides an interface defining an et_transaction entity.
 */
interface EtTransactionInterface extends ContentEntityInterface {

  /**
   * Sets the title for the et_transaction.
   *
   * @param string $title
   *   The short title of the feed.
   *
   * @return \Drupal\expense_tracker\EtTransactionInterface
   *   The class instance that this method is called on.
   */
  public function setTitle($title);

  /**
   * Return when the feed was modified last time.
   *
   * @return int
   *   The timestamp of the last time the feed was modified.
   */
  public function getCreated();

  /**
   * Sets the last modification of the feed.
   *
   * @param int $created
   *   The timestamp when the feed was modified.
   *
   * @return \Drupal\expense_tracker\EtTransactionInterface
   *   The class instance that this method is called on.
   */
  public function setCreated($created);


  /**
   * Returns the runtime of the feed in seconds.
   *
   * @return int
   *   The refresh rate of the feed in seconds.
   */
  public function getRuntime();

  /**
   * Sets the runtime of the feed in seconds.
   *
   * @param int $runtime
   *   The refresh rate of the feed in seconds.
   *
   * @return \Drupal\expense_tracker\EtTransactionInterface
   *   The class instance that this method is called on.
   */
  public function setRuntime($runtime);


  /**
   * Returns the last time where the feed was checked for new items.
   *
   * @return int
   *   The timestamp when new items were last checked for.
   */
  public function getAnonymousVoteAllow();

  /**
   * Sets the time when this feed was queued for refresh, 0 if not queued.
   *
   * @param int $anonymous_vote_allow
   *   The timestamp of the last refresh.
   *
   * @return \Drupal\expense_tracker\EtTransactionInterface
   *   The class instance that this method is called on.
   */
  public function setAnonymousVoteAllow($anonymous_vote_allow);

  /**
   * Returns the time when this feed was queued for refresh, 0 if not queued.
   *
   * @return int
   *   The timestamp of the last refresh.
   */
  public function getCancelVoteAllow();

  /**
   * Sets the time when this feed was queued for refresh, 0 if not queued.
   *
   * @param int $cancel_vote_allow
   *   The timestamp of the last refresh.
   *
   * @return \Drupal\expense_tracker\EtTransactionInterface
   *   The class instance that this method is called on.
   */
  public function setCancelVoteAllow($cancel_vote_allow);


  /**
   * Returns the time when this feed was queued for refresh, 0 if not queued.
   *
   * @return int
   *   The timestamp of the last refresh.
   */
  public function getResultVoteAllow();

  /**
   * Sets the time when this feed was queued for refresh, 0 if not queued.
   *
   * @param int $result_vote_allow
   *   The timestamp of the last refresh.
   *
   * @return \Drupal\expense_tracker\EtTransactionInterface
   *   The class instance that this method is called on.
   */
  public function setResultVoteAllow($result_vote_allow);

  /**
   * Returns if the et_transaction is open.
   *
   * @return bool
   *   TRUE if the et_transaction is open.
   */
  public function isOpen();

  /**
   * Returns if the et_transaction is closed.
   *
   * @return bool
   *   TRUE if the et_transaction is closed.
   */
  public function isClosed();

  /**
   * Sets the et_transaction to closed.
   */
  public function close();

  /**
   * Sets the et_transaction to open.
   */
  public function open();

  /**
   * @todo: Refactor - doesn't belong here.
   *
   * @return mixed
   */
  public function hasUserVoted();

  /**
   * Get all options for this et_transaction.
   *
   * @return array
   *   Associative array of option keys and values.
   */
  public function getOptions();

  /**
   * Get the values of each vote option for this et_transaction.
   *
   * @return array
   *   Associative array of option values.
   */
  public function getOptionValues();

  /**
   * Get all the votes of this et_transaction.
   *
   * @return array
   */
  public function getVotes();

}
