<?php

namespace Drupal\expense_tracker;

use Drupal\Core\Entity\EntityStorageInterface;
use Drupal\Core\Session\AccountInterface;

/**
 * Defines a common interface for et_transaction entity controller classes.
 */
interface EtTransactionStorageInterface extends EntityStorageInterface {

  /**
   * Save a user's vote.
   *
   * @param array $options
   *
   * @return mixed
   *
   * @deprecated in Drupal 8.x-1.0.
   *   Use \Drupal\et_transaction\EtTransactionVoteStorageInterface::saveVote() instead.
   *
   * @see \Drupal\et_transaction\EtTransactionVoteStorageInterface::saveVote()
   */
  public function saveVote(array $options);

  /**
   * Cancel a user's vote.
   *
   * @param EtTransactionInterface $et_transaction
   * @param AccountInterface $account
   *
   * @return mixed
   *
   * @deprecated in Drupal 8.x-1.0.
   *   Use \Drupal\et_transaction\EtTransactionVoteStorageInterface::cancelVote() instead.
   *
   * @see \Drupal\et_transaction\EtTransactionVoteStorageInterface::cancelVote()
   */
  public function cancelVote(EtTransactionInterface $et_transaction, AccountInterface $account = NULL);

  /**
   * Get total votes for a et_transaction.
   *
   * @param EtTransactionInterface $et_transaction
   *
   * @return mixed
   *
   * @deprecated in Drupal 8.x-1.0.
   *   Use \Drupal\et_transaction\EtTransactionVoteStorageInterface::getTotalVotes() instead.
   *
   * @see \Drupal\et_transaction\EtTransactionVoteStorageInterface::getTotalVotes()
   */
  public function getTotalVotes(EtTransactionInterface $et_transaction);

  /**
   * Get all votes for a et_transaction.
   *
   * @param EtTransactionInterface $et_transaction
   *
   * @return mixed
   *
   * @deprecated in Drupal 8.x-1.0.
   *   Use \Drupal\et_transaction\EtTransactionVoteStorageInterface::getVotes() instead.
   *
   * @see \Drupal\et_transaction\EtTransactionVoteStorageInterface::getVotes()
   */
  public function getVotes(EtTransactionInterface $et_transaction);

  /**
   * Delete a user's votes for a et_transaction.
   *
   * @param EtTransactionInterface $et_transaction
   *
   * @return mixed
   *
   * @deprecated in Drupal 8.x-1.0.
   *   Use \Drupal\et_transaction\EtTransactionVoteStorageInterface::deleteVotes() instead.
   *
   * @see \Drupal\et_transaction\EtTransactionVoteStorageInterface::deleteVotes()
   */
  public function deleteVotes(EtTransactionInterface $et_transaction);

  /**
   * Get a user's votes for a et_transaction.
   *
   * @param EtTransactionInterface $et_transaction
   *
   * @return mixed
   *
   * @deprecated in Drupal 8.x-1.0.
   *   Use \Drupal\et_transaction\EtTransactionVoteStorageInterface::getUserVote() instead.
   *
   * @see \Drupal\et_transaction\EtTransactionVoteStorageInterface::getUserVote()
   */
  public function getUserVote(EtTransactionInterface $et_transaction);

  /**
   * Get the most recent et_transaction posted on the site.
   *
   * @return mixed
   */
  public function getMostRecentEtTransaction();

  /**
   * Find all duplicates of a et_transaction by matching the title.
   *
   * @param EtTransactionInterface $et_transaction
   *
   * @return mixed
   */
  public function getEtTransactionDuplicates(EtTransactionInterface $et_transaction);

  /**
   * Returns all expired et_transactions.
   *
   * @return \Drupal\expense_tracker\EtTransactionInterface[]
   *
   */
  public function getExpiredEtTransactions();

}
